========================================================================================
PyMVPA -- Multivariate Pattern Analysis in Python |build-status| |coverage-status| |doi|
========================================================================================

.. |doi|
   image:: https://img.shields.io/badge/doi-10.3389%2Fneuro.11.003.2009-green.svg
   :target: http://dx.doi.org/10.3389/neuro.11.003.2009
   :alt: Original PyMVPA publication

.. |build-status|
   image:: https://secure.travis-ci.org/PyMVPA/PyMVPA.png
           ?branch=master
   :target: http://travis-ci.org/PyMVPA/PyMVPA
   :alt: PyMVPA travis-ci build status

.. |coverage-status|
   image:: https://coveralls.io/repos/PyMVPA/PyMVPA/badge.png
           ?branch=master
   :target: https://coveralls.io/r/PyMVPA/PyMVPA
   :alt: PyMVPA coveralls coverage status

For information how to install PyMVPA please see
doc/source/installation.rst .

Further information and access to binary packages is available from the
project website at http://www.pymvpa.org .
